@@ -297,15 +297,15 @@ test_indep_clust_subset <- function(x,  model1="EII", model2="EII",
 
   if(is.matrix(x[[1]])) {
     # Density matrices for each mixture component
-    logphi1 <-  mclust::cdens(model1, x[[1]][subset1, ], logarithm=TRUE, EM.View1.param)
+    logphi1 <-  mclust::cdens(modelName=model1, data=x[[1]][subset1, ], logarithm=TRUE, parameters=EM.View1.param)
   } else {
-    logphi1 <-  mclust::cdens(model1, x[[1]][subset1], logarithm=TRUE, EM.View1.param)
+    logphi1 <-  mclust::cdens(modelName=model1, data=x[[1]][subset1], logarithm=TRUE, parameters=EM.View1.param)
   }
 
   if(is.matrix(x[[1]])) {
-    logphi2 <- mclust::cdens(model2, x[[2]][subset2, ], logarithm=TRUE, EM.View2.param)
+    logphi2 <- mclust::cdens(modelName=model2, data=x[[2]][subset2, ], logarithm=TRUE, parameters=EM.View2.param)
   } else {
-    logphi2 <- mclust::cdens(model2, x[[2]][subset2], logarithm=TRUE, EM.View2.param)
+    logphi2 <- mclust::cdens(modelName=model2, data=x[[2]][subset2], logarithm=TRUE, parameters=EM.View2.param)
   }
 
   n <- nrow(logphi1)
